print("import: 'py'")
import py

print("import: 'py.code'")
import py.code

print("import: 'py.io'")
import py.io

print("import: 'py.log'")
import py.log

print("import: 'py.path'")
import py.path

print("import: 'py.process'")
import py.process

